@@ -43,7 +43,7 @@ static void	cb_toggle_tree (GtkAction *action, gpointer data);
 
 static const GtkActionEntry menu_entries[] =
 {
-	{ "File", NULL, N_("_File") },
+	{ "Monitor", NULL, N_("_Monitor") },
 	{ "Edit", NULL, N_("_Edit") },
 	{ "View", NULL, N_("_View") },
 	{ "Help", NULL, N_("_Help") },
@@ -102,8 +102,8 @@ static const GtkRadioActionEntry radio_menu_entries[] =
 
 static const char ui_info[] =
 "  <menubar name=\"MenuBar\">"
-"    <menu name=\"FileMenu\" action=\"File\">"
-"      <menuitem name=\"FileQuitMenu\" action=\"Quit\" />"
+"    <menu name=\"MonitorMenu\" action=\"Monitor\">"
+"      <menuitem name=\"MonitorQuitMenu\" action=\"Quit\" />"
 "    </menu>"
 "    <menu name=\"EditMenu\" action=\"Edit\">"
 "      <menuitem name=\"EditStopProcessMenu\" action=\"StopProcess\" />"
@@ -742,7 +742,7 @@ create_main_window (ProcData *procdata)
 
 	devices_box = create_disk_view (procdata);
 	gtk_widget_show(devices_box);
-	tab_label3 = gtk_label_new (_("Devices"));
+	tab_label3 = gtk_label_new (_("File Systems"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), devices_box, tab_label3);
 
 	g_signal_connect (G_OBJECT (notebook), "switch-page",
